@@ -24,7 +24,7 @@ from oslo_utils import uuidutils
 from octaviaclient.osc.v2 import constants as const
 from octaviaclient.osc.v2 import utils as v2_utils
 
-PROVISIONING_STATUS = ['ACTIVE', 'DELETED', 'ERROR', 'PENDING_CREATE',
+PROVISIONING_STATUS = ['ACTIVE', 'ERROR', 'PENDING_CREATE',
                        'PENDING_UPDATE', 'PENDING_DELETE']
 
 OPERATING_STATUS = ['ONLINE', 'DRAINING', 'OFFLINE', 'DEGRADED', 'ERROR',
@@ -89,6 +89,13 @@ class CreateLoadBalancer(command.ShowOne):
             metavar='<vip_qos_policy_id>',
             help="Set QoS policy ID for VIP port. Unset with 'None'.",
         )
+        parser.add_argument(
+            '--additional-vip',
+            metavar='subnet-id=<name-or-uuid>[,ip-address=<ip>]',
+            action='append',
+            help="Expose an additional VIP on the load balancer. This "
+                 "parameter can be provided more than once."
+        )
 
         parser.add_argument(
             '--project',
@@ -130,7 +137,7 @@ class CreateLoadBalancer(command.ShowOne):
         parser.add_argument(
             '--wait',
             action='store_true',
-            help='Wait for action to complete',
+            help='Wait for action to complete.',
         )
 
         _tag.add_tag_option_to_parser_for_create(
@@ -181,7 +188,7 @@ class DeleteLoadBalancer(command.Command):
         parser.add_argument(
             'loadbalancer',
             metavar='<load_balancer>',
-            help="Load balancers to delete (name or ID)"
+            help="Load balancers to delete (name or ID)."
         )
         parser.add_argument(
             '--cascade',
@@ -193,7 +200,7 @@ class DeleteLoadBalancer(command.Command):
         parser.add_argument(
             '--wait',
             action='store_true',
-            help='Wait for action to complete',
+            help='Wait for action to complete.',
         )
 
         return parser
@@ -228,7 +235,7 @@ class FailoverLoadBalancer(command.Command):
         parser.add_argument(
             '--wait',
             action='store_true',
-            help='Wait for action to complete',
+            help='Wait for action to complete.',
         )
 
         return parser
@@ -438,7 +445,7 @@ class SetLoadBalancer(command.Command):
         parser.add_argument(
             '--wait',
             action='store_true',
-            help='Wait for action to complete',
+            help='Wait for action to complete.',
         )
 
         _tag.add_tag_option_to_parser_for_set(parser, 'load balancer')
@@ -496,7 +503,7 @@ class UnsetLoadBalancer(command.Command):
         parser.add_argument(
             '--wait',
             action='store_true',
-            help='Wait for action to complete',
+            help='Wait for action to complete.',
         )
 
         _tag.add_tag_option_to_parser_for_unset(parser, 'load balancer')
